@@ -15,6 +15,11 @@
 use strict;
 use warnings;
 
+{
+    package Doit;
+    our $VERSION = '0.022_50';
+}
+
 {
     package Doit::Log;
 
@@ -314,8 +319,6 @@ use warnings;
 {
     package Doit;
 
-    our $VERSION = '0.021_53';
-
     sub import {
 	warnings->import;
 	strict->import;
@@ -1209,13 +1212,18 @@ use warnings;
 							 my $diffref = _qx('diff', '-u', $filename, $tempfile);
 							 $diff = $$diffref;
 							 unlink $tempfile;
+							 if (length $diff) {
+							     $diff = "Replace existing file $filename with diff:\n$diff";
+							 } else {
+							     $diff = "(diff not available, probably no diff utility installed)";
+							 }
 						     } else {
 							 $diff = "(diff not available, error in tempfile creation ($!))";
 						     }
 						 } else {
 						     $diff = "(diff not available, neither IPC::Run nor File::Temp available)";
 						 }
-						 "Replace existing file $filename with diff:\n$diff";
+						 $diff;
 					     }
 					 } else {
 					     "Create new file $filename with content:\n$content";
